@@ -4,7 +4,7 @@ import json
 from sqlalchemy import create_engine
 import psycopg2
 
-def get_data(query, engine):
+def get_data(query, engine, close_connection = False):
     """
     make a query in a database
     """
@@ -14,8 +14,9 @@ def get_data(query, engine):
     ## make select query
     table = pd.read_sql(query, engine)
 
-    ## close connection    
-    engine.close()
+    # ## close connection
+    if close_connection:
+        engine.close()
     return table
 
 def write_table(table, table_name, schema, engine, if_exists = 'append', chunksize = 10_000, index= False, close_connection = False):
